@@ -5,7 +5,7 @@ from json import dumps
 from typing import Any, Literal, Optional, cast
 
 from aiohttp import ClientSession
-from httpx import Request, AsyncClient
+from httpx import Request, Response, AsyncClient, HTTPStatusError
 
 from . import settings
 from ._typing import _ApiResponse
@@ -21,35 +21,31 @@ class Api:
     '''请求的 API 地址'''
     proxy: bool
     '''是否使用代理服务器'''
-    params: Optional[dict[str, Any]]
-    '''请求的参数'''
-    data: Optional[dict[str, Any]]
-    '''请求的数据'''
     # 初始化
     def __init__(
         self,
         url: str,
-        proxy: bool,
-        *,
-        params: Optional[dict[str, Any]]=None,
-        data: Optional[dict[str, Any]]=None
+        proxy: bool
     ) -> None:
         '''初始化'''
         self.url = url
         self.proxy = proxy
-        self.params = params
-        self.data = data
         return
     
     # 请求发送
     async def _request(
         self,
         method: Literal['get', 'post'],
+        *,
+        params: Optional[dict[str, Any]]=None,
+        data: Optional[dict[str, Any]]=None
     ) -> _ApiResponse:
         '''请求发送
 
         参数:
             method (Literal[&#39;get&#39;, &#39;post&#39;]): API 调用方法
+            params (Optional[dict[str, Any]]): 请求的参数
+            data (Optional[dict[str, Any]]): 请求的数据
 
         返回:
             Response: 收到的响应
@@ -73,8 +69,8 @@ class Api:
                 request = Request(
                     method,
                     self.url,
-                    params=self.params,
-                    data=cast(dict, dumps(self.data)) if self.data is not None else self.data,
+                    params=params,
+                    data=cast(dict, dumps(data)) if data is not None else data,
                     headers=headers
                 )
                 
@@ -84,28 +80,46 @@ class Api:
                 response = await session.request(
                     method,
                     self.url,
-                    params=self.params,
-                    data=cast(dict, dumps(self.data)) if self.data is not None else self.data,
+                    params=params,
+                    data=cast(dict, dumps(data)) if data is not None else data,
                     headers=headers,
-                    proxy=settings.proxy if len(settings.proxy) > 0 else None,
+                    proxy=settings.proxy if len(settings.proxy) > 0 and self.proxy else None,
                 )
         
         # 处理接收到的响应
-        response.raise_for_status()
+        if isinstance(response, Response):
+            try:
+                response.raise_for_status()
+            except HTTPStatusError as exception:
+                if exception.response.status_code == 400:
+                    return response
+                else:
+                    raise exception
+        else:
+            if response.status == 400:
+                return response
+            else:
+                response.raise_for_status()
         return response
     
-    async def post(self) -> _ApiResponse:
+    async def post(self, data: Optional[dict[str, Any]]=None) -> _ApiResponse:
         '''发送 POST 请求
 
-        返回:
-            _ApiResponse: 收到的响应
-        '''
-        return await self._request('post')
-    
-    async def get(self) -> _ApiResponse:
-        '''发送 GET 请求
+        参数:
+            data (Optional[dict[str, Any]]): 请求的数据
 
         返回:
             _ApiResponse: 收到的响应
         '''
-        return await self._request('get')
+        return await self._request('post', data=data)
+    
+    async def get(self, params: Optional[dict[str, Any]]=None) -> _ApiResponse:
+        '''发送 GET 请求
+
+        参数:
+            params (Optional[dict[str, Any]]): 请求的参数
+
+        返回:
+            _ApiResponse: 收到的响应
+        '''
+        return await self._request('get', params=params)
